unit QrToEnImg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  EnDiGrph,
  EnImgScr,
  EnMisc,        { for MinFloat }
  EnJpgGr,       { for TJpegGraphic }
  EnTifGr,       { for TTiffGraphic }
  EnWmfGr,       { for TMetaFileGraphic }
  StdCtrls, ExtCtrls, ComCtrls, FileCtrl, Quickrpt, QRPrntr;

function CreateTIFFromQR(Rep          : TQRPrinter;
                         FileName     : String) : Boolean;
function CreateJpgFromQR(Rep          : TQRPrinter;
                         FileName     : String;
                         Var FileList : TStringList) : Boolean;
implementation

function CreateTifFromQR(Rep      : TQRPrinter;
                         FileName : String) : Boolean;
var
  Page       : TMetaFile;
  CurPage    : integer;
  PageIndx   : integer;
  TIFEnObj   : TTiffGraphic;
  Stream     : TFileStream;
  MultiImage : Boolean;
begin
  Result := FALSE;
  TIFEnObj := TTiffGraphic.Create;
  Try
    Try
       MultiImage := (Rep.PageCount > 1);
       PageIndx   := 0;
       For CurPage := 1 To Rep.PageCount Do
       begin
         PageIndx :=  PageIndx + 1;
         Page     := Rep.GetPage(CurPage);
         TIFEnObj.Assign(Page);

         IF (CurPage = 1) Or (Not MultiImage) Then
         begin
           TIFEnObj.SaveToFile(FileName);
         end
         else
         begin
           Stream   := TFileStream.Create(FileName, fmOpenReadWrite);
           Try
             TIFEnObj.AppendToStream(Stream);
           Finally
             Stream.Free;
           End;
         end;
       end;
       Result := (PageIndx = Rep.PageCount);
    Finally
      TIFEnObj.Free;
    End;
  Except;
    Result := FALSE;
  End;
end;

function CreateJpgFromQR(Rep          : TQRPrinter;
                         FileName     : String;
                         Var FileList : TStringList) : Boolean;
var
  Page       : TMetaFile;
  CurPage    : integer;
  PageIndx   : integer;
  JPGEnObj   : TJpegGraphic;
  Stream     : TFileStream;
  MultiImage : Boolean;
  FName      : string;
  FirstName  : string;
  PathName   : string;
  DotPos     : Byte;
begin
  FileList.Clear;

  FirstName  := ExtractFileName(FileName);
  DotPos := Pos('.', FirstName);
  if DotPos > 0 then
    FirstName := Copy(FirstName, 1, DotPos-1);
  PathName   := ExtractFilePath(FileName);

  IF Copy(PathName,Length(PathName),1) = '\' Then
    PathName := Copy(PathName,1,Length(PathName)-1);

  Result := FALSE;
  JPGEnObj := TJpegGraphic.Create;
  Try
    Try
       MultiImage := (Rep.PageCount > 1);
       PageIndx   := 0;
       For CurPage := 1 To Rep.PageCount Do
       begin
         PageIndx :=  PageIndx + 1;
         Page     := Rep.GetPage(CurPage);

         IF Not MultiImage Then
         begin
           FName := FileName;
         end
         else
         begin
           FName := PathName + '\' + FirstName + Format('%.3d', [CurPage]) + '.JPG';
         end;

         JPGEnObj.Assign(Page);
         JPGEnObj.SaveToFile(FName);
         FileList.Add(FName);
       end;
       Result := (PageIndx = Rep.PageCount);
    Finally
      JPGEnObj.Free;
    End;
  Except;
    Result := FALSE;
  End;
end;

end.
